/******************************************************************************
  Copyright 2013 Tom Cornall

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.  
 ******************************************************************************/
#ifndef KBD_H
#define KBD_H

#include <LUFA/Drivers/USB/USB.h>
#include <stdlib.h>
#include "eeprom.h"
#include "sr.h"
#include "vref.h"

#define KBD_COLS 23
#define KBD_ROWS 4

#define KBD_DEBOUNCE_LEN 6
#define KBD_DEBOUNCE_MIN 0
#define KBD_DEBOUNCE_MAX (KBD_DEBOUNCE_LEN - 1)
#define KBD_DEBOUNCE_THRESH (KBD_DEBOUNCE_LEN / 2 - 1)

#define KBD_SC_IGNORED 0
#define KBD_SC_CAL_HI  1
#define KBD_SC_CAL_LO  2


#ifndef BEAMSPRING_BOARD_REV
#error board revision not specified
#endif

#if BEAMSPRING_BOARD_REV <= 2
#define KBD_ROWS_PIN PINB
#define KBD_ROW1_IP PB0
#define KBD_ROW2_IP PB1
#define KBD_ROW3_IP PB2
#define KBD_ROW4_IP PB3
#endif

#if BEAMSPRING_BOARD_REV == 3
#define KBD_ROWS_PIN PIND
#define KBD_ROW1_IP PD0
#define KBD_ROW2_IP PD1
#define KBD_ROW3_IP PD2
#define KBD_ROW4_IP PD3
#endif

extern int8_t kbd[KBD_COLS][KBD_ROWS];
extern uint8_t kbdMatrix[KBD_COLS][KBD_ROWS];

void kbdCalibrate(void);
void kbdFillReport(USB_KeyboardReport_Data_t *kbdReport);
void kbdLoadMatrix(void);
void kbdStoreMatrix(void);
void kbdScan(void);

#endif
