#ifndef DIAGINTERFACE_H
#define DIAGINTERFACE_H

#include <cstdlib>
#include <cstring>
#include <hidapi.h>
#include <iostream>
#include <sstream>
#include <stdexcept>
#include <string>
#include <vector>
#include "diag_types.h"

class DiagInterface
{
    public:
        DiagInterface(void);
        ~DiagInterface(void);
        unsigned short vref(void);
        void setVref(unsigned short val);
        void storeVref(void);
        void autoCalibrate(void);
        std::vector<std::vector<bool>> keyStates(void);
        void enterBootloader(void);
        std::vector<std::vector<unsigned char>> scancodes(void);
        void setScancodes(std::vector<std::vector<unsigned char>> codes);
        void setScancode(int col, int row, unsigned char scancode);
        void loadScancodes(void);
        void storeScancodes(void);

    private:
        hid_device *dev;
        unsigned char currState[8];

        hid_device * openDevice(void);
        void closeDevice(void);
        void sendCmd(DiagReportCommand cmd, unsigned char p1, unsigned char p2,
                unsigned char p3);
        void sendCmd(DiagReportCommand cmd, unsigned int data);
        void sendCtrl(unsigned char buf[8]);
        void setState(DiagReportState state, bool block = true);
        void updateState(void);
};

#endif
