#ifndef FRONTEND_H
#define FRONTEND_H

#include <QDebug>
#include <QFileDialog>
#include <QGridLayout>
#include <QGroupBox>
#include <QHBoxLayout>
#include <QLabel>
#include <QMessageBox>
#include <QPushButton>
#include <QScrollArea>

#if QT_VERSION >= 0x050000
#include <QScroller>
#endif

#include <QSpinBox>
#include <QTimer>
#include <QVBoxLayout>
#include <QWidget>
#include <stdexcept>
#include "DiagInterface.h"
#include "ImportExport.h"
#include "Key.h"

class Frontend: public QWidget
{
    Q_OBJECT

    public:
        Frontend(DiagInterface &diag, QWidget *parent = NULL);
        virtual ~Frontend(void);

    private:
        DiagInterface &diag;
        QSpinBox *vrefSpinBox;
        QTimer *vrefMaskTimer;
        QPushButton *autoCalButton;
        QPushButton *storeVrefButton;
        QPushButton *bootloaderButton;
        QScrollArea *matrixScrollArea;
        QWidget *matrixWidget;
        QGridLayout *matrixGrid;
        QTimer *keyStatesTimer;
        std::vector<std::vector<Key *>> keyWidgets;
        QPushButton *storeMatrixButton;
        QPushButton *loadMatrixButton;

    private slots:
        void updateVref(void);
        void vrefValueChanged(int);
        void setVrefFromBox(void);
        void autoCalButtonClicked(void);
        void autoCalComplete(void);
        void storeVrefButtonClicked(void);
        void bootloaderButtonClicked(void);
        void buildMatrix(void);
        void updateKeyStates(void);
        void storeMatrixButtonClicked(void);
        void storeMatrixComplete(void);
        void loadMatrixButtonClicked(void);
        void loadMatrixComplete(void);
        void importMatrixButtonClicked(void);
        void exportMatrixButtonClicked(void);
};

#endif
